==> floodcast-0.0.11.tar.bz2: floodcast-0.0.11/src/status.h <==
/*
    status.h  -  Floodcast standalone-server status-window

    Copyright (c) 2002 by Ryan Cumming
    Copyright (c) 2004 by Stefan Gehn <metz AT gehn.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef _STATUS_H
#define _STATUS_H

#include <qmap.h>
#include <qobject.h>
#include <qdatetime.h>
#include <qdns.h>

#include <kdialogbase.h>
#include <klistview.h>

class QTimer;
class FloodcastPlugin;
class QSocket;
class QHostAddress;
class KPopupMenu;
class IcecastServer;

class HostItem : public QObject, public KListViewItem
{
	Q_OBJECT
	public:
		HostItem(KListView *parent, const QHostAddress &);
		virtual ~HostItem();

	protected:
		QHostAddress mAddress;
		QDns *mLookup;
		QDateTime mConnectTime;
		QTimer *mUpdateTimer;

	protected slots:
		void updateTime();
		void slotLookupComplete();
};


class FloodcastStatus : public KDialogBase
{
	Q_OBJECT
	public:
		FloodcastStatus();
		void setServer(IcecastServer *server);

	protected slots:
		void slotServerDestroyed();
		void gainedConnection(QSocket *);
		void lostConnection(QSocket *);

		void showContextMenu(QListViewItem *, const QPoint &pos);
		void disconnectClient();

	protected:
		QMap<QSocket *, HostItem *> mEntryMap;
		KListView *mListView;
		KPopupMenu *mContextMenu;
		IcecastServer *mServer;
};

#endif

==> floodcast-0.0.12.tar.bz2: floodcast-0.0.12/src/status.h <==
/*
    status.h  -  Floodcast standalone-server status-window

    Copyright (c) 2002 by Ryan Cumming
    Copyright (c) 2004 by Stefan Gehn <metz AT gehn.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef _STATUS_H
#define _STATUS_H

#include <qmap.h>
#include <qobject.h>
#include <qdatetime.h>
#include <qdns.h>

#include <kdialogbase.h>
#include <klistview.h>

class QTimer;
class QCheckBox;
class FloodcastPlugin;
class IcecastClientSocket;
class QHostAddress;
class KPopupMenu;
class IcecastServer;

class HostItem : public QObject, public KListViewItem
{
	Q_OBJECT
	public:
		HostItem(KListView *parent, const QHostAddress &a, const QString &ua);
		HostItem(KListView *parent, const QString &a, const QString &ua, int connectedSecs);
		virtual ~HostItem();

	protected:
		void setup(const QString &ua);

		QHostAddress mAddress;
		QDns *mLookup;
		QDateTime mConnectTime;
		QTimer *mUpdateTimer;

	protected slots:
		void updateTime();
		void slotLookupComplete();
};


class FloodcastStatus : public KDialogBase
{
	Q_OBJECT
	public:
		FloodcastStatus();
		void setServer(IcecastServer *server);

		QCheckBox *mChkActive;

	public slots:
		void setActive(bool);

	protected slots:
		void slotServerDestroyed();
		void gainedConnection(IcecastClientSocket *);
		void lostConnection(IcecastClientSocket *);

		void showContextMenu(QListViewItem *, const QPoint &pos);
		void disconnectClient();
		void slotUser1();

	protected:
		QMap<IcecastClientSocket *, HostItem *> mEntryMap;
		KListView *mListView;
		KPopupMenu *mContextMenu;
		IcecastServer *mServer;
};

#endif
